@@ -19,6 +19,7 @@ from .constant import DirSaveFile, FieldConstantResponse, CONSTANT_MAP_FORMAT_FI
     ParamMessageUploadMediaSdk, Display
 from .custom_mimetypes import CustomMimetypes
 from .dir import APP_TMP_DATA_DIR, STATIC_DATA_DIR
+from urllib.parse import quote
 
 logger = logging.getLogger()
 
@@ -175,9 +176,10 @@ class MobioMediaSDK(object):
                 f.write(file_byte)
         from .utils import file_capacity, convert_bytes
         capacity = convert_bytes(file_capacity(dist_file))
-        url = os.path.join(host_by_merchant_id, self.folder_static, merchant_id, type_media, filename)
+        decode_filename = quote(filename)
+        url = os.path.join(host_by_merchant_id, self.folder_static, merchant_id, type_media, decode_filename)
         if short_link:
-            url = os.path.join(host_by_merchant_id, self.folder_static, filename)
+            url = os.path.join(host_by_merchant_id, self.folder_static, decode_filename)
         logger.debug("upload_without_kafka()::url:: %s" % (time.time() - time_start))
         data_send_producer = {
             ParamMessageSaveInfoFile.FILENAME: filename,
@@ -280,9 +282,10 @@ class MobioMediaSDK(object):
         )
         host_by_merchant_id = self._get_host_by_merchant_id(merchant_id=merchant_id)
         logger.debug("upload_with_kafka()::get_host_by_merchant_id:: %s" % (time.time() - time_start))
-        url = os.path.join(host_by_merchant_id, self.folder_static, merchant_id, type_media, filename)
+        decode_filename = quote(filename)
+        url = os.path.join(host_by_merchant_id, self.folder_static, merchant_id, type_media, decode_filename)
         if short_link:
-            url = os.path.join(host_by_merchant_id, self.folder_static, filename)
+            url = os.path.join(host_by_merchant_id, self.folder_static, decode_filename)
         data_send_producer = {
             ParamMessageUploadMediaSdk.FILENAME: filename,
             ParamMessageUploadMediaSdk.MERCHANT_ID: merchant_id,
@@ -330,9 +333,10 @@ class MobioMediaSDK(object):
         )
         host_by_merchant_id = self._get_host_by_merchant_id(merchant_id=merchant_id)
         logger.info("create_public_url_without_file :: host_by_merchant_id :: %s " % host_by_merchant_id)
-        url = os.path.join(host_by_merchant_id, self.folder_static, merchant_id, type_media, filename)
+        decode_filename = quote(filename)
+        url = os.path.join(host_by_merchant_id, self.folder_static, merchant_id, type_media, decode_filename)
         if short_link:
-            url = os.path.join(host_by_merchant_id, self.folder_static, filename)
+            url = os.path.join(host_by_merchant_id, self.folder_static, decode_filename)
         logger.info("create_public_url_without_file :: url :: %s " % url)
         logger.info("create_public_url_without_file :: local_path :: %s " % dist_file)
         time_start = time.time()
